package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.PowerBox;

/**
 * 动力箱柜Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-20
 */
public interface PowerBoxMapper
{
    /**
     * 查询动力箱柜
     *
     * @param id 动力箱柜主键
     * @return 动力箱柜
     */
     PowerBox selectPowerBoxById(Long id);

    /**
     * 查询动力箱柜列表
     *
     * @param powerBox 动力箱柜
     * @return 动力箱柜集合
     */
     List<PowerBox> selectPowerBoxList(PowerBox powerBox);

    /**
     * Select power box by code power box.
     *
     * @param boxCode the box code
     * @return the power box
     * @author chen.cheng
     */
    PowerBox selectPowerBoxByCode(String boxCode);

    /**
     * 新增动力箱柜
     *
     * @param powerBox 动力箱柜
     * @return 结果
     */
     int insertPowerBox(PowerBox powerBox);

    /**
     * 修改动力箱柜
     *
     * @param powerBox 动力箱柜
     * @return 结果
     */
     int updatePowerBox(PowerBox powerBox);

    /**
     * 删除动力箱柜
     *
     * @param id 动力箱柜主键
     * @return 结果
     */
     int deletePowerBoxById(Long id);

    /**
     * 批量删除动力箱柜
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deletePowerBoxByIds(Long[] ids);
}
